ternary_plot: Create a base ternary plot

View source: R/ternary_diagram.R

ternary_plotR Documentation

Create a base ternary plot

Description

Create the base ggplot object associated with a ternary_frame.

Usage

ternary_plot(
  frame = NULL,
  show_grid = TRUE,
  show_outline = TRUE,
  show_labels = TRUE,
  grid_ticks = seq(0.1, 0.9, 0.1)
)

Arguments

frame

Optional ternary_frame object. If NULL, a default ternary frame is created with no centering and no scaling.

show_grid

Logical. If TRUE, draw the ternary grid.

show_outline

Logical. If TRUE, draw the ternary triangle outline.

show_labels

Logical. If TRUE, draw corner labels.

grid_ticks

Numeric vector of grid levels.

Value

A ggplot2 object with the ternary_frame attached as attribute.


coda.plot documentation built on April 12, 2026, 9:06 a.m.