View source: R/ternary_diagram.R
| add_ternary_pc | R Documentation |
Add principal component paths to a ternary plot
add_ternary_pc(
p,
X,
group = NULL,
pcs = 1:2,
basis = coda.base::ilr_basis(3),
n = 600,
eps = 0.001,
...
)
p |
A |
X |
A numeric matrix or data frame with exactly three columns. |
group |
Optional grouping variable of length |
pcs |
Integer vector indicating which principal components to draw. |
basis |
An ilr basis. Default is |
n |
Number of sampled points per PC path. |
eps |
Small positive threshold used to keep the path inside the simplex. |
... |
Further arguments passed to |
A ggplot2 object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.