View source: R/ternary_diagram.R
| ternary_coords | R Documentation |
Convert a compositional dataset into ternary plotting coordinates under a given
ternary_frame.
ternary_coords(frame, X, transform = TRUE, group = NULL)
frame |
A |
X |
A numeric matrix or data frame with exactly three columns. |
transform |
Logical. If |
group |
Optional grouping variable of length |
A data frame with compositional columns c1, c2, c3,
ternary coordinates .x, .y, and optionally group.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.